/// <reference types="node" />
import { AxiosProxyConfig, AxiosResponse } from 'axios';
import { Agent } from 'https';
export interface ApiClientArgs {
    port?: number;
    fingerprint?: string;
    sid?: string;
    server?: string;
    proxy?: AxiosProxyConfig;
    apiVersion?: string;
    unsafe?: boolean;
    unsafeAutoAccept?: boolean;
    context?: string;
}
export interface LoginArgs {
    username?: string;
    password?: string;
    apiKey?: string;
    continueLastSession?: boolean;
    domain?: string;
    readOnly?: boolean;
}
export default class ApiClient {
    private _port;
    private _fingerprint?;
    private _sid?;
    private _server;
    private _proxy?;
    private _apiVersion?;
    private _unsafe;
    private _unsafeAutoAccept;
    private _approvedFingerprint;
    private _context;
    private _agent;
    constructor({ port, fingerprint, sid, server, proxy, apiVersion, unsafe, unsafeAutoAccept, context }: ApiClientArgs);
    login({ username, password, apiKey, continueLastSession, domain, readOnly }: LoginArgs): Promise<AxiosResponse<any>>;
    logout(): Promise<AxiosResponse<any>>;
    publish(): Promise<AxiosResponse<any>>;
    discard(): Promise<AxiosResponse<any>>;
    apiCall(command: string, payload?: {
        [p: string]: Object;
    }, sid?: string, waitForTask?: boolean): Promise<AxiosResponse<any>>;
    isFingerprintOK(): Promise<boolean>;
    private askYesNoQuestion;
    private saveFingerprintToFile;
    private readFingerprintFromFile;
    private static isFingerprintsFileExist;
    private static getAllFingerprints;
    private getServerFingerprint;
    waitForTasksFun(tasks: any[]): Promise<AxiosResponse<any>>;
    waitForTaskFun(taskId: string): Promise<AxiosResponse<any>>;
    apiCallFewTimesOnError(command: string, payload: {
        [p: string]: Object;
    }, attempts: number): Promise<AxiosResponse>;
    get port(): number;
    set port(value: number);
    get fingerprint(): string | undefined;
    set fingerprint(value: string | undefined);
    get sid(): string | undefined;
    set sid(value: string | undefined);
    get server(): string;
    set server(value: string);
    get proxy(): AxiosProxyConfig | undefined;
    set proxy(value: AxiosProxyConfig | undefined);
    get apiVersion(): string | undefined;
    set apiVersion(value: string | undefined);
    get unsafe(): boolean;
    set unsafe(value: boolean);
    get unsafeAutoAccept(): boolean;
    set unsafeAutoAccept(value: boolean);
    get approvedFingerprint(): boolean;
    set approvedFingerprint(value: boolean);
    get context(): string;
    set context(value: string);
    get agent(): Agent;
    set agent(value: Agent);
}
