"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/* eslint-disable no-console */
const typescript_logging_1 = require("typescript-logging");
const guid_typescript_1 = require("guid-typescript");
const customLogger_1 = require("./customLogger");
var ItpLogLevel;
(function (ItpLogLevel) {
    ItpLogLevel[ItpLogLevel["Trace"] = 0] = "Trace";
    ItpLogLevel[ItpLogLevel["Debug"] = 1] = "Debug";
    ItpLogLevel[ItpLogLevel["Info"] = 2] = "Info";
    ItpLogLevel[ItpLogLevel["Warn"] = 3] = "Warn";
    ItpLogLevel[ItpLogLevel["Error"] = 4] = "Error";
    ItpLogLevel[ItpLogLevel["Fatal"] = 5] = "Fatal";
})(ItpLogLevel || (ItpLogLevel = {}));
class log {
    constructor(component) {
        const componentName = `${log.rootCategory.name}:${component}(${log.currentIterationId})`;
        this.category = new typescript_logging_1.Category(componentName, log.rootCategory);
    }
    static init() {
        //log.customConfig is using for our custom logger, if you want to change to the default logger (console) -
        // in the following two lines, replace log.customConfig with log.defaultConfig
        typescript_logging_1.CategoryServiceFactory.setConfigurationCategory(log.defaultConfig, log.rootCategory, true);
        typescript_logging_1.CategoryServiceFactory.setDefaultConfiguration(log.customConfig);
        const logMethod = console.log;
        console.log = function () {
            // 1. Convert args to a normal array
            // eslint-disable-next-line prefer-rest-params
            const args = Array.prototype.slice.call(arguments);
            // 2. Prepend log prefix log string
            args.unshift(`${log.rootCategory.name}:console(${log.currentIterationId}):`);
            // 3. Pass along arguments to console.log
            logMethod.apply(console, args);
        };
    }
    trace(message) {
        return this.category.trace(() => message);
    }
    debug(message) {
        return this.category.debug(() => message);
    }
    info(message) {
        return this.category.info(() => message);
    }
    warn(message) {
        return this.category.warn(() => message);
    }
    error(message, error) {
        return this.category.error(() => message, () => (!error ? null : error));
    }
    fatal(message, error) {
        return this.category.fatal(() => message, () => (!error ? null : error));
    }
    getLogLevel() {
        return this.category.logLevel.valueOf();
    }
}
log.rootCategory = new typescript_logging_1.Category(`API sdk`);
log.currentIterationId = guid_typescript_1.Guid.create()
    .toString()
    .substr(24);
log.defaultConfig = new typescript_logging_1.CategoryConfiguration(process.env.NODE_ENV === 'production' ? typescript_logging_1.LogLevel.Info : typescript_logging_1.LogLevel.Trace, typescript_logging_1.LoggerType.Console, new typescript_logging_1.CategoryLogFormat(undefined, false));
log.customConfig = new typescript_logging_1.CategoryConfiguration(typescript_logging_1.LogLevel.Info, typescript_logging_1.LoggerType.Custom, new typescript_logging_1.CategoryLogFormat(), (category, runtimeSettings) => new customLogger_1.default(category, runtimeSettings));
log.init();
function getLogger(componentName) {
    return new log(componentName);
}
exports.default = getLogger;
//# sourceMappingURL=log.js.map